---
name: Bug report
about: Report an issue to help improve RAGNARDoc
title: ""
labels: bug
assignees: ""
---

### Bug

<!-- Describe the buggy behavior you have observed. -->

...

### Steps to reproduce

<!-- Describe the sequence of steps for reproducing the bug. -->

...

### Version

<!-- Copy the output of `ragnardoc --version`. -->

...

### Python version

<!-- Copy the output of `python --version`. -->

...

<!-- ⚠️ ATTENTION: When sharing screenshots, attachments, or other data make sure not to include any sensitive information. -->
